@@ -97,7 +97,7 @@ let run (g : G.guestfs) root (ops : ops) =
     ) in
 
   (* Store the passwords and set them all at the end. *)
-  let passwords = Hashtbl.create 13 in
+  let passwords = Hashtbl.create 16 in
   let set_password user pw =
     if Hashtbl.mem passwords user then
       error (f_"multiple --root-password/--password options set the \
@@ -116,7 +116,7 @@ let run (g : G.guestfs) root (ops : ops) =
     else (
       match meth with
       | "osinfo" | "libosinfo" ->
-         Some (Inject_virtio_win.from_libosinfo g root)
+         error (f_"method '%s' is no longer supported") meth;
       | path ->
          Some (Inject_virtio_win.from_path g root path)
     )
@@ -142,7 +142,7 @@ let run (g : G.guestfs) root (ops : ops) =
       (* If the mode string is octal, add the OCaml prefix for octal values
        * so it is properly converted as octal integer.
        *)
-      let mode = if String.is_prefix mode "0" then "0o" ^ mode else mode in
+      let mode = if String.starts_with "0" mode then "0o" ^ mode else mode in
       g#chmod (int_of_string mode) path
 
     | `Chown (uid, gid, path) ->
